# StarFlow

## Original code

[https://github.com/pgodet/star_flow](https://github.com/pgodet/star_flow)

## Code license

See [LICENSE](LICENSE).

## Pretrained weights license

Not specified.

## Citation

```
@article{godet2020starflow,
  title={STaRFlow: A SpatioTemporal Recurrent Cell for Lightweight Multi-Frame Optical Flow Estimation},
  author={Godet, Pierre and Boulch, Alexandre and Plyer, Aur{\'e}lien and Le Besnerais, Guy},
  journal={arXiv preprint arXiv:2007.05481},
  year={2020}
}
```
